@@ -1,21 +1,19 @@
 //! Provides the [`PureClone`] trait, which is a restrictive form of `Clone` that does not mutate
-//! the containing [`Cell`].
+//! the containing [`Cell`](crate::cell::Cell).
 //!
-//! Conceptually, the relationship between [`Copy`], [`Clone`], and `PureClone` can be
-//! thought of as follows:
+//! Conceptually, the relationship between [`Copy`], [`Clone`], and `PureClone` can be thought of as
+//! follows:
 //! ```text
 //! Copy: PureClone: Clone
 //! ```
 //!
-//! `PureClone` is `unsafe` because the `clone` implementation must not mutate the
-//! content of `Cell` through the `&self` reference it gets with interior
-//! mutability. See this [Stack Overflow answer] and this [Rust forum thread] for
-//! details.
+//! `PureClone` is `unsafe` because the `clone` implementation must not mutate the content of `Cell`
+//! through the `&self` reference it gets with interior mutability. See this [Stack Overflow answer]
+//! and this [Rust forum thread] for details.
 //!
 //! When this [`crate`] is built with the `"derive"` feature, the [`PureClone`](derive@PureClone)
 //! proc macro can be used to derive `PureClone` for user types.
 //!
-//! [`Cell`]: crate::cell::Cell
 //! [Rust forum thread]:
 //! https://users.rust-lang.org/t/why-does-cell-require-copy-instead-of-clone/5769/3
 //! [Stack Overflow answer]:
@@ -24,15 +22,46 @@
 /// A derive macro that generates impls of the traits [`PureClone`] and [`Clone`].
 ///
 /// See the [crate#soundness] doc on why this macro also generates a `Clone` impl.
+///
+/// # Examples
+///
+/// ```
+/// use std::rc::Rc;
+/// use clone_cell::{cell::Cell, clone::PureClone};
+///
+/// // Note: This also generates a `Clone` impl.
+/// #[derive(PureClone)]
+/// struct Foo<T> {
+///     p: Rc<T>, // `Rc<T>` is always `PureClone`.
+///     t: Option<T>, // `Option<T>` is `PureClone` if `T` is.
+///     x: i32, // `i32` is `PureClone`.
+/// }
+///
+/// let p = Rc::new(-42);
+/// let f = Cell::new(Foo {
+///     p: p.clone(),
+///     t: Some(0),
+///     x: 0,
+/// });
+///
+/// f.set(Foo {
+///     p,
+///     t: Some(42),
+///     x: 21,
+/// });
+///
+/// assert_eq!(*f.get().p, -42);
+/// assert_eq!(f.get().t, Some(42));
+/// assert_eq!(f.get().x, 21);
+/// ```
 #[cfg(feature = "derive")]
 pub use crate::derive::PureClone;
 
 /// The `PureClone` trait, which is a subtrait of [`Clone`].
 ///
-/// See the [module] documentation for more information.
-///
-/// [module]: self
+/// See the [module](self) documentation for more information.
 pub unsafe trait PureClone: Clone {
+    /// The `pure_clone` method.
     #[inline]
     fn pure_clone(&self) -> Self {
         Clone::clone(self)
@@ -41,7 +70,11 @@ pub unsafe trait PureClone: Clone {
 
 /// Implementations for types that are known to have compliant `clone` implementations.
 mod impls {
-    use std::rc::{Rc, Weak};
+    use alloc::{
+        boxed::Box,
+        rc::{Rc, Weak},
+        vec::Vec,
+    };
 
     use super::PureClone;
 
